==> haskell-path-0.8.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path
version:              0.8.0
visibility:           public
id:                   path-0.8.0-AY5y0gYdqESJXiSGiZV0zj
key:                  path-0.8.0-AY5y0gYdqESJXiSGiZV0zj
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  2aab5bf13e8f276d2b2d2c7119eb108b
exposed:              True
exposed-modules:      Path Path.Internal Path.Posix Path.Windows
import-dirs:          /usr/lib/ghc-8.10.1/site-local/path-0.8.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/path-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/path-0.8.0
hs-libraries:         HSpath-0.8.0-AY5y0gYdqESJXiSGiZV0zj
depends:
    aeson-1.4.7.1-ANEJrhOqgvGIzgMZodlboL base-4.14.0.0 deepseq-1.4.4.0
    exceptions-0.10.4 filepath-1.4.2.1
    hashable-1.3.0.0-EAzOv9XkxZx208nV7jdDUC template-haskell-2.16.0.0
    text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.8.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path
version:              0.8.0
visibility:           public
id:                   path-0.8.0-B26QE2MdrxC5hJJqvDJBNQ
key:                  path-0.8.0-B26QE2MdrxC5hJJqvDJBNQ
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  906a12acb74a149762419189eb35dee8
exposed:              True
exposed-modules:      Path Path.Internal Path.Posix Path.Windows
import-dirs:          /usr/lib/ghc-8.10.1/site-local/path-0.8.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/path-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/path-0.8.0
hs-libraries:         HSpath-0.8.0-B26QE2MdrxC5hJJqvDJBNQ
depends:
    aeson-1.5.1.0-9ZdAa5h0lJg1SCgI7etVaW base-4.14.0.0 deepseq-1.4.4.0
    exceptions-0.10.4 filepath-1.4.2.1
    hashable-1.3.0.0-EAzOv9XkxZx208nV7jdDUC template-haskell-2.16.0.0
    text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
